@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1400';
+our $VERSION = '0.1500';
 
 use MIDI::Simple;
 use Music::Duration;
@@ -11,6 +11,8 @@ use Moo;
 use strictures 2;
 use namespace::clean;
 
+use constant TICKS => 96; # Per quarter note
+
 
 sub BUILD {
     my ( $self, $args ) = @_;
@@ -275,7 +277,7 @@ sub flam {
     my ($self, $spec, $patch) = @_;
     my $x = $MIDI::Simple::Length{$spec};
     my $y = $MIDI::Simple::Length{ $self->sixtyfourth };
-    my $z = sprintf '%0.f', ($x - $y) * 96;
+    my $z = sprintf '%0.f', ($x - $y) * TICKS;
     my $accent = sprintf '%0.f', $self->score->Volume / 2;
     $self->accent_note($accent, $self->sixtyfourth, $patch);
     $self->note('d' . $z, $patch);
@@ -292,6 +294,21 @@ sub roll {
 }
 
 
+sub crescendo_roll {
+    my ($self, $span, $length, $spec, $patch) = @_;
+    $patch ||= $self->snare;
+    my ($i, $j) = @$span;
+    my $x = $MIDI::Simple::Length{$length};
+    my $y = $MIDI::Simple::Length{$spec};
+    my $z = sprintf '%0.f', $x / $y;
+    for my $n (1 .. $z) {
+        #warn(__PACKAGE__,' ',__LINE__," MARK: ",$i,"\n");
+        $self->accent_note($i, $spec, $patch);
+        $i += $j;
+    }
+}
+
+
 sub set_time_sig {
     my $self = shift;
     if (@_) {
@@ -328,7 +345,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1400
+version 0.1500
 
 =head1 SYNOPSIS
 
@@ -351,11 +368,11 @@ version 0.1400
 
  $d->rest($d->whole);
 
+ $d->metronome44;  # 4/4 time for the number of bars
+
  $d->flam($d->quarter, $d->snare);
  $d->roll($d->eighth, $d->thirtysecond);
 
- $d->metronome44;  # 4/4 time for the number of bars
-
  # Alternate kick and snare
  $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
     for 1 .. $d->beats * $d->bars;
@@ -573,6 +590,16 @@ duration B<length> in B<spec> increments.
 
 If not provided the B<snare> is used for the B<patch>.
 
+=head2 crescendo_roll
+
+  $d->crescendo_roll( [$i, $j], $length, $spec, $patch );
+
+Add a drum roll to the score, where the B<patch> is played for
+duration B<length> in B<spec> increments at increasing or decreasing
+volumes from B<i> to B<j>.
+
+If not provided the B<snare> is used for the B<patch>.
+
 =head2 set_time_sig
 
   $d->set_time_sig('5/4');
